@@ -4,15 +4,15 @@ import subprocess
 PIPE=subprocess.PIPE
 from distutils import log
 
-OUR_VERSION_BASE_RE_STR="(\d+)(\.(\d+)(\.(\d+))?)?((a|b|c|rc)(\d+))?"
+OUR_VERSION_BASE_RE_STR="(\d+)(\.(\d+)(\.(\d+))?)?((a|b|c)(\d+))?(\.dev(\d+))?"
 try:
     # If we can import pyutil.version_class then use its regex.
     from pyutil import version_class
     VERSION_BASE_RE_STR = version_class.VERSION_BASE_RE_STR
-except ImportError:
+except (ImportError, AttributeError):
     # Else (perhaps a bootstrapping problem),then we'll use this
     # regex, which was copied from the pyutil source code on
-    # 2007-10-30.
+    # 2010-09-02.
     VERSION_BASE_RE_STR=OUR_VERSION_BASE_RE_STR
 
 def get_text(nodelist):
@@ -119,7 +119,7 @@ def update(pkgname, verfilename, revision_number=False, loud=False, abort_if_sna
 
     changelog = doc.getElementsByTagName("changelog")[0]
     patches = changelog.getElementsByTagName("patch")
-    regexstr = "^TAG %s-(%s)" % (pkgname, VERSION_BASE_RE_STR,)
+    regexstr = "^TAG %s-(%s)$" % (pkgname, VERSION_BASE_RE_STR)
     version_re = re.compile(regexstr)
     last_tag = None
     count_since_last_patch = 0
